/******************************************************************************
* Marcel Bresink Software-Systeme
*
* Project HardwareMonitor
* File HardwareMonitor.js
*
*           Created: 2005-07-18
* Last Modification: 2010-12-16
*            Author: Marcel Bresink
*
* Copyright (c) 2005 - 2010 by Marcel Bresink Software-Systeme. All rights reserved
******************************************************************************/

var PluginController;
var updateTimer = null;
var flipShown = false;
var animation = { duration:0, starttime:0, to:1.0, now:0.0, from:0.0, firstElement:null, timer:null };

var WINDOW_HEIGHT = 152;
var WINDOW_BACKSIDE_WIDTH = 426;
var windowInitialWidth = window.innerWidth;
var MAX_LABEL_WIDTH = 175.0;


function widgetDidLaunch()
{
	var doneButton = document.getElementById("doneButton");
	var doneText = "Done";
	
	if (PluginController) {
		PluginController.setWidgetIdentifier(widget.identifier);
		PluginController.setMaximumSensorNameWidth(MAX_LABEL_WIDTH);
		localizeUIElement("sensorPopUpLabel1");
		localizeUIElement("sensorPopUpLabel2");
		localizeUIElement("tempUnitLabel");
		
		doneText = PluginController.localizedStringForElementWithName("doneButton");
	}
	createGenericButton(doneButton, doneText, hideBack);
	updateBackside();
	
	if (window.widget) {
		widget.onshow = widgetHasBecomeActive;
		widget.onhide = widgetHasBecomeInactive;
	}
	widgetHasBecomeActive();
}


function showBack()
{
	document.getElementById("flip").style.display = "none";
	document.getElementById("fliprollie").style.display = "none";
 
	if (window.widget) {
		if (window.innerWidth >= WINDOW_BACKSIDE_WIDTH) {
			widget.prepareForTransition("ToBack");
			window.resizeTo(WINDOW_BACKSIDE_WIDTH, WINDOW_HEIGHT);
		}
		else {
			window.resizeTo(WINDOW_BACKSIDE_WIDTH, WINDOW_HEIGHT);
			widget.prepareForTransition("ToBack");
		}
	}
		
	document.getElementById("front").style.display = "none";
	document.getElementById("back").style.display = "block";
	
	if (window.widget)
		setTimeout("widget.performTransition();", 0);
}


function hideBack()
{
	document.getElementById("flip").style.display = "block";

	if (window.widget) {
		if (window.innerWidth >= windowInitialWidth) {
			widget.prepareForTransition("ToFront");
			window.resizeTo(windowInitialWidth, WINDOW_HEIGHT);
		}
		else {
			window.resizeTo(windowInitialWidth, WINDOW_HEIGHT);
			widget.prepareForTransition("ToFront");
		}
	}
		
	document.getElementById("back").style.display = "none";
	document.getElementById("front").style.display = "block";
	
	if (window.widget)
		setTimeout("widget.performTransition();", 0);
}


function clickWebButton(event)
{
	if (window.widget && PluginController)
		widget.openURL(PluginController.localizedURLForMasterApplication());
}


function mousemove(event)
{
	if (! flipShown) {
		if (animation.timer != null) {
			clearInterval(animation.timer);
			animation.timer = null;
		}
		
		var starttime = (new Date).getTime() - 13;
		
		animation.duration = 500;
		animation.starttime = starttime;
		animation.firstElement = document.getElementById("flip");
		animation.timer = setInterval("animate();", 13);
		animation.from = animation.now;
		animation.to = 1.0;
		animate();
		flipShown = true;
	}
}


function mouseexit(event)
{
	if (flipShown) {
		if (animation.timer != null) {
			clearInterval(animation.timer);
			animation.timer = null;
		}
		
		var starttime = (new Date).getTime() - 13;
		
		animation.duration = 500;
		animation.starttime = starttime;
		animation.firstElement = document.getElementById("flip");
		animation.timer = setInterval("animate();", 13);
		animation.from = animation.now;
		animation.to = 0.0;
		animate();
		flipShown = false;
	}
}


function animate()
{
	var t;
	var ease;
	var time = (new Date).getTime();
	
	t = limit3(time - animation.starttime, 0, animation.duration);
	if (t >= animation.duration) {
		clearInterval(animation.timer);
		animation.timer = null;
		animation.now = animation.to;
	}
	else {
		ease = 0.5 - (0.5 * Math.cos(Math.PI * t / animation.duration));
		animation.now = computeNextFloat(animation.from, animation.to, ease);
	}
	animation.firstElement.style.opacity = animation.now;
}


function limit3(a, b, c)
{
	return (a < b) ? b : ((a > c) ? c : a);
}


function computeNextFloat(from, to, ease)
{
	return from + (to - from) * ease;
}


function enterflip(event)
{
	document.getElementById("fliprollie").style.display = "block";
}


function exitflip(event)
{
	document.getElementById("fliprollie").style.display = "none";
}


function widgetHasBecomeActive()
{
	updateDisplay();
	if (! updateTimer)
		updateTimer = setInterval("updateDisplay();", 2000);
}


function widgetHasBecomeInactive()
{
	clearInterval(updateTimer);
	updateTimer = null;
}


function localizeUIElement(name)
{
	var localizedString = null;
	
	if (PluginController)
		localizedString = PluginController.localizedStringForElementWithName(name);
	if (! localizedString)
		localizedString = name;
	document.getElementById(name).innerHTML = localizedString;
}


function updateDisplay()
{
	if (PluginController) {
		document.getElementById("sensorLabel1").innerHTML = PluginController.localizedSensorNameAtDisplayIndex(0);
		document.getElementById("sensorLabel2").innerHTML = PluginController.localizedSensorNameAtDisplayIndex(1);
		document.getElementById("sensorReading1").innerHTML = PluginController.localizedReadingAtDisplayIndex(0);
		document.getElementById("sensorReading2").innerHTML = PluginController.localizedReadingAtDisplayIndex(1);
		document.getElementById("messageText").innerHTML = PluginController.localizedStatusMessage();
		document.getElementById("sensorType1").src = PluginController.relativePathForTypeIconAtDisplayIndex(0);
		document.getElementById("sensorType2").src = PluginController.relativePathForTypeIconAtDisplayIndex(1);
	}
}


function updateBackside()
{
	if (PluginController) {
		updateSensorPopUpButtonWithIdAndIndex("sensorPopUp1", 0);
		updateSensorPopUpButtonWithIdAndIndex("sensorPopUp2", 1);
		document.getElementById("tempUnitPopUp").selectedIndex = PluginController.preferredTemperatureUnitIndex();
		document.getElementById("versionMessage").innerHTML = PluginController.localizedVersionMessage();
	}
}


function updateSensorPopUpButtonWithIdAndIndex(identification, index)
{
	var popUpButton = document.getElementById(identification);
	var count, i;
	var currentOption;
	
	if (! popUpButton || ! PluginController)
		return;
	
	while (popUpButton.hasChildNodes())
		popUpButton.removeChild(popUpButton.firstChild);
		
	count = PluginController.numberOfAvailableSensors();
	currentOption = document.createElement("option");
	currentOption.innerText = PluginController.localizedStringForElementWithName("emptySensorOption");
	popUpButton.appendChild(currentOption);
	for (i = 0; i < count; i++) {
		currentOption = document.createElement("option");
		currentOption.innerText = PluginController.localizedDifferentiatingSensorNameAtIndex(i);
		popUpButton.appendChild(currentOption);
	}
	
	popUpButton.selectedIndex = PluginController.preferredSensorIndexAtDisplayIndex(index) + 1;
}


function sensorPopUpChanged(popUp)
{
	var identification = popUp.getAttribute("id");
	var	popUpIndex = 0;
	
	if (identification == "sensorPopUp1")
		popUpIndex = 0;
	else if (identification == "sensorPopUp2")
		popUpIndex = 1;
		
	if (PluginController) {
		PluginController.setPreferredSensorIndexForDisplayIndex(popUp.selectedIndex - 1, popUpIndex);
		updateDisplay();
	}
}


function tempUnitChanged(popUp)
{
	if (PluginController) {
		PluginController.setTemperatureUnitIndex(popUp.selectedIndex);
		updateDisplay();
	}
}
